# Worksheet 1: Assembly Programming with Docker Integration

This project is part of the **Worksheet 1** task, focusing on assembly programming and integration with Docker for build and run processes.

## Project Overview

This repository contains assembly language programs and supporting files to demonstrate basic programming concepts in assembly language. The workflow involves writing assembly code, integrating it with C for execution, and containerizing the build process using Docker.

### Files in the Repository

- **Assembly Files**
  - `task1.asm`: First task in assembly programming.
  - `task2.asm`: Second task in assembly programming.
  - `task3.asm`: Third task in assembly programming.

- **C Files**
  - `driver.c`: Main driver file that calls the assembly program.
  - `print_int.c`: Helper function to print integers.

- **Include Files**
  - `asm_io.asm` and `asm_io.inc`: Assembly IO routines.

- **Build Files**
  - `Makefile`: Automates the build process.
  - `Dockerfile`: Containerizes the build and execution process.

## Getting Started

### Prerequisites

- **Docker**: Ensure Docker is installed on your machine.
- **NASM**: An assembler for x86 assembly.
- **GCC**: A C compiler to link the assembly and C code.

### Building and Running

1. **Using Docker**:
   - Build the Docker container:
     ```bash
     docker build -t asm_project .
     ```
   - Run the container:
     ```bash
     docker run --rm asm_project
     ```

2. **Locally**:
   - Compile using `make`:
     ```bash
     make
     ```
   - Run the program:
     ```bash
     ./program
     ```

## Project Structure

worksheet_1/
├── README.md          # Project documentation (to be created or updated by you)
├── Makefile           # Build file for automating compilation
├── Dockerfile         # Docker configuration for containerized builds
├── src/               # Directory containing all source files
│   ├── asm_io.asm     # Provided Assembly IO code
│   ├── asm_io.inc     # Provided IO include file
│   ├── driver.c       # Main C program calling assembly functions
│   ├── print_int.c    # Helper C program for printing integers
│   ├── task1.asm      # Assembly code for Task 1
│   ├── task2.asm      # Assembly code for Task 2
│   ├── task3.asm      # Assembly code for Task 3


## Authors

- Hazal Veziroglu

## License

This project is licensed under the MIT License. See the `LICENSE` file for details.

## Acknowledgments

- UWE Course Material on Assembly Programming
- Online assembly programming resources and communities.
